/*  
  Datum.java

  11.03.2001: tk, sourcecode released under the GPL.

  Copyright (c)2001 by SoPra2001 Gruppe 14, University of Dortmund
  mail for contact: thomas.kindler@gmx.de

  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the 
  Free Software Foundation; either version 2 of the License, or (at your 
  option) any later version. Please read the included "copying.txt" file,
  or the full License at http://www.gnu.org/copyleft for more details.
*/


package logic;
import java.io.Serializable;

public class Datum implements Serializable {

  public final static boolean VORMITTAG  = false;
  public final static boolean NACHMITTAG = true;

  private int zeitcode;


  /**
   * Erzeugt ein neues Datumsobjekt
   *
   */
  public Datum(int tag, boolean nachmittag) {
    setDatum(tag, nachmittag);
  }

  /**
   * Erzeugt ein Datum aus einem Datumsstring zurck
   *
   */
  public Datum(String datum) throws NumberFormatException
  {
    String  tageszeit = datum.substring(datum.length()-1, datum.length());
    boolean nachmittag;

    if (tageszeit.equalsIgnoreCase("V"))
      nachmittag = false;
    else if (tageszeit.equalsIgnoreCase("N"))
      nachmittag = true;
    else throw new NumberFormatException();

    String tag = datum.substring(0, datum.length()-1);

    setDatum( Integer.parseInt(tag), nachmittag);
  }

  /**
   * Kopiert ein bestehendes Datumsobjekt
   *
   */
  public Datum(Datum datum) {
    this.zeitcode = datum.zeitcode;
  }


  public void setDatum( int tag, boolean nachmittag) {
    if (tag < 1)
      throw new IllegalArgumentException("tag muss >= 1 sein.");

    zeitcode = (tag-1)*2 + (nachmittag ? 1 : 0);
  }


  /**
   * Erhoeht das Datum um eine Einheit.
   * d.h. 1V -> 1N,  1N -> 2V, etc..
   *
   */
  public Datum next() {
    zeitcode++;
    return this;
  }

  /**
   * Wandelt ein Datum in einen String um.
   * z.b. "1V" fuer 1. Tag, vormittag   *
   *
   */
  public String toString() {
    return (zeitcode/2+1) + ((zeitcode % 2 == 0) ? "V" : "N");
  }


  /**
   * Object.hashCode() muss hier ueberschrieben werden, denn wenn
   * a.equals(b) ist, muss auch a.hashcode() == b.hashcode() gelten.
   *
   */
  public int hashCode() {
    return zeitcode;
  }


  /**
   * Diese Methode ueberschreibt Object.equals(), und prueft zwei
   * daten auf Gleichheit.
   */
  public boolean equals(Object other) {
    return this.zeitcode==((Datum)other).zeitcode;
  }


}