/*  
  Planung.java

  11.03.2001: tk, sourcecode released under the GPL.

  Copyright (c)2001 by SoPra2001 Gruppe 14, University of Dortmund
  mail for contact: thomas.kindler@gmx.de

  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the 
  Free Software Foundation; either version 2 of the License, or (at your 
  option) any later version. Please read the included "copying.txt" file,
  or the full License at http://www.gnu.org/copyleft for more details.
*/


package logic;
import  java.io.*;
import  java.util.*;

public class Planung implements Serializable, StatusConst {

  private Vector  aufgabenListe = new Vector();
  private Projekt projekt;
  private int     stundenlohn = 12;

  public Planung( Projekt projekt ) {
    this.projekt = projekt;

    Aufgabe sonstiges = new Aufgabe( "Sonstiges", 0, 0 );
    try {
      this.addAufgabe(sonstiges);
    } catch(Exception e) {}
  }

  public Aufgabe getAufgabe(String name)
  {
    Iterator iter = aufgabenListe.listIterator();
    while (iter.hasNext()) {
      Aufgabe  aufgabe=(Aufgabe)iter.next();
      if (name.compareToIgnoreCase(aufgabe.getName())==0)
        return aufgabe;
    }
    return null;
  }


  public void addAufgabe(Aufgabe aufgabe) throws Exception {
    if (getAufgabe(aufgabe.getName()) != null)
      throw new Exception( "Diese Aufgabe gibt es schon." );

    aufgabenListe.add(aufgabe);
  }


  public void remAufgabe(Aufgabe aufgabe)
  {
    Nutzerverwaltung nutzerverw = projekt.getNutzerverwaltung();

    for (int i=0; i<nutzerverw.getNutzerCount(); i++) {
      Nutzer nutzer = nutzerverw.getNutzerAt(i);
      Stundenplan stdplan = nutzer.getStundenplan();

      Enumeration enum = stdplan.getTerminListe();
      while (enum.hasMoreElements()) {
        Datum datum = (Datum)enum.nextElement();
        Termin termin = stdplan.getTermin(datum);

        if (termin.getAufgabe() == aufgabe)
          stdplan.removeTermin(datum);
      }
    }
    aufgabenListe.remove(aufgabe);
  }


  public int getAufgabenCount() {
    return aufgabenListe.size();
  }


  public Aufgabe getAufgabeAt(int index) {
    return (Aufgabe)aufgabenListe.get(index);
  }


  public void setStundenlohn(int lohn) {
    stundenlohn = lohn;
  }

  public int getStundenlohn() {
    return stundenlohn;
  }

  public int getPersonenStunden() {
    int personenStunden = 0;

    Iterator iter = aufgabenListe.iterator();
    while (iter.hasNext()) {
      Aufgabe aufgabe = (Aufgabe)iter.next();
      personenStunden += aufgabe.getDauer();
    }
    return personenStunden;
  }

  public void update() {
    Nutzerverwaltung nutzerverw = projekt.getNutzerverwaltung();

    Iterator iter = aufgabenListe.iterator();
    while (iter.hasNext()) {
      Aufgabe aufgabe = (Aufgabe)iter.next();

      aufgabe.setDauer(0);
      aufgabe.setPersonenZahl(0);
      aufgabe.setStatus( GEPLANT );

      boolean  inarbeit = false;
      boolean  erledigt = true;

      for (int i=0; i<nutzerverw.getNutzerCount(); i++) {
        Nutzer nutzer = nutzerverw.getNutzerAt(i);
        Stundenplan stdplan = nutzer.getStundenplan();

        boolean diesePersonArbeitetDaDran = false;

        Enumeration enum = stdplan.getTerminListe();
        while (enum.hasMoreElements()) {
          Datum datum = (Datum)enum.nextElement();
          Termin termin = stdplan.getTermin(datum);

          if (termin.getAufgabe() == aufgabe) {
            aufgabe.setDauer(aufgabe.getDauer() + termin.getDauer());
            diesePersonArbeitetDaDran = true;

            // wenn schon jemand so einen termin hat, is die
            // aufgabe in arbeit.
            inarbeit = true;

            // wenn nicht alles fertig is, isse nich fertig.
            if (!termin.getErledigt())
              erledigt = false;
          }
        }

        if (diesePersonArbeitetDaDran)
          aufgabe.setPersonenZahl(aufgabe.getPersonenZahl()+1);
      }

      if (inarbeit)
        aufgabe.setStatus( INARBEIT );
      if (erledigt && inarbeit)
        aufgabe.setStatus( ERLEDIGT );
    }
  }

}
